SnmpKit.MIB.Import (snmpkit v2.0.1)

Turns parsed or compiled MIB data into the name_to_oid / name_to_meta maps the registry merges: object OIDs, base syntax, textual conventions, display hints, access, status and description.

Summary

Functions

Name-to-OID map for a compiled symbol table. Relative OIDs are resolved against the other symbols and against known (names already registered, such as the built-in enterprises or ifEntry).

Functions

extract_meta_from_symbols(symbols)

extract_mib_mappings(mib_data, known \\ SnmpKit.MIB.Builtin.name_to_oid())

extract_name_to_oid_from_symbols(symbols, known \\ %{})

Name-to-OID map for a compiled symbol table. Relative OIDs are resolved against the other symbols and against known (names already registered, such as the built-in enterprises or ifEntry).

load_mib_file_and_extract_mappings(mib_path)

object_meta(defn, tc_map)

syntax_base_from(syntax)

textual_convention_from(syntax)