mix snmpkit.get (snmpkit v2.0.1)
Retrieves objects from a device and prints them one per line.
mix snmpkit.get HOST OID [OID ...] [options]
mix snmpkit.get 192.168.1.1 sysDescr.0 sysUpTime.0
mix snmpkit.get switch:1161 1.3.6.1.2.1.1.5.0 -c private -v 2cSeveral OIDs go into one PDU. Options:
-c,--community- community string (default from config)-v,--version-1,2cor3-t,--timeout- per-PDU timeout in milliseconds-r,--retries- retries per PDU-p,--port- UDP port (also accepted asHOST:PORT)--numeric- print OIDs instead of names--raw- print the raw value instead of the formatted one